@@ -1,4 +1,4 @@
-/* $Id: data_service.c,v 1.14 2005/09/27 08:07:10 nclapies Exp $
+/* $Id: data_service.c,v 1.21 2005/12/06 13:22:08 nclapies Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
@@ -33,6 +33,13 @@
 #include <lasso/xml/dst_modify.h>
 #include <lasso/xml/dst_modify_response.h>
 #include <lasso/xml/soap_binding_correlation.h>
+#include <lasso/xml/soap_fault.h>
+#include <lasso/xml/is_redirect_request.h>
+
+#include <xmlsec/xmltree.h>
+#include <xmlsec/xmldsig.h>
+#include <xmlsec/templates.h>
+#include <xmlsec/crypto.h>
 
 
 struct _LassoDataServicePrivate
@@ -40,6 +47,7 @@ struct _LassoDataServicePrivate
 	gboolean dispose_has_run;
 	LassoDiscoResourceOffering *offering;
 	GList *credentials;
+	LassoSoapFault *fault;
 };
 
 /*****************************************************************************/
@@ -115,6 +123,26 @@ lasso_data_service_add_query_item(LassoDataService *service,
 	return item;
 }
 
+gint
+lasso_data_service_need_redirect_user(LassoDataService *service, const char *redirectUrl)
+{
+	LassoWsfProfile *profile;
+	LassoSoapBody *body;
+	LassoSoapFault *fault;
+	LassoUtilityStatus *status;
+	LassoSoapDetail *detail;
+	GList *iter;
+
+	/* Find a SOAP fault element */
+	service->private_data->fault = lasso_soap_fault_new();
+	service->private_data->fault->faultcode = g_strdup(LASSO_SOAP_FAULT_CODE_SERVER);
+	detail = lasso_soap_detail_new();
+	detail->any = g_list_append(detail->any, lasso_is_redirect_request_new(redirectUrl));
+	service->private_data->fault->Detail = detail;
+
+	return 0;
+}
+
 /**
  * lasso_data_service_init_query
  * @service: a #LassoDataService
@@ -167,19 +195,16 @@ lasso_data_service_init_query(LassoDataService *service, const char *select,
 		return LASSO_ERROR_UNIMPLEMENTED;
 	}
 
-	profile->soap_envelope_request = lasso_wsf_profile_build_soap_envelope(
-		NULL, NULL);
-	profile->soap_envelope_request->Body->any = g_list_append(
-			profile->soap_envelope_request->Body->any, query);
+	lasso_wsf_profile_init_soap_request(LASSO_WSF_PROFILE(service), LASSO_NODE(query));
 
-	if (security_mech_id)
-		description = lasso_discovery_get_description_auto(
-			offering, security_mech_id);
-	else
-		description = lasso_discovery_get_description_auto(
-			offering, LASSO_SECURITY_MECH_NULL);
+	if (!security_mech_id)
+		description = LASSO_DISCO_DESCRIPTION(offering->ServiceInstance->Description->data);
+	else {
+		description = lasso_discovery_get_description_auto(offering, security_mech_id);
+	}
 	if (!description)
 		return -1;
+	lasso_wsf_profile_set_description(LASSO_WSF_PROFILE(service), description);
 
 	if (description->Endpoint != NULL) {
 		profile->msg_url = g_strdup(description->Endpoint);
@@ -196,8 +221,8 @@ lasso_data_service_init_query(LassoDataService *service, const char *select,
 				LassoSamlAssertion *credential = LASSO_SAML_ASSERTION(
 					iter->data);
 				if (strcmp(credentialRef, credential->AssertionID) == 0)
-					lasso_wsf_profile_add_saml_authentication(
-						LASSO_WSF_PROFILE(service), credential);
+				  //lasso_wsf_profile_add_saml_authentication(
+				  //	LASSO_WSF_PROFILE(service), credential);
 				iter = iter->next;
 			}
 	}
@@ -205,6 +230,47 @@ lasso_data_service_init_query(LassoDataService *service, const char *select,
 	return 0;
 }
 
+/**
+ * lasso_data_service_get_redirect_request_url:
+ * @service: a #LassoDataService
+ * @message: the dst query message
+ *
+ * Tells if Attribute Provider needs user interaction.
+ *
+ * Return value: TRUE if needed; or FALSE otherwise.
+ **/
+gchar*
+lasso_data_service_get_redirect_request_url(LassoDataService *service)
+{
+	LassoSoapFault *fault = NULL;
+	LassoIsRedirectRequest *redirect_request = NULL;
+	GList *iter;
+
+	iter = LASSO_WSF_PROFILE(service)->soap_envelope_response->Body->any;
+	while (iter) {
+		if (LASSO_IS_SOAP_FAULT(iter->data) == TRUE) {
+			fault = LASSO_SOAP_FAULT(iter->data);
+			break;
+		}
+		iter = iter->next;
+	}
+	if (!fault)
+		return NULL;
+
+	iter = fault->Detail->any;
+	while (iter) {
+		if (LASSO_IS_IS_REDIRECT_REQUEST(iter->data) == TRUE) {
+			redirect_request = LASSO_IS_REDIRECT_REQUEST(iter->data);
+			break;
+		}
+		iter = iter->next;
+	}
+	if (!redirect_request)
+		return NULL;
+
+	return g_strdup(redirect_request->redirectURL);
+}
+
 /**
  * lasso_data_service_process_query_msg:
  * @service: a #LassoDataService
@@ -222,19 +288,32 @@ lasso_data_service_process_query_msg(LassoDataService *service, const char *mess
 	LassoDstQuery *query;
 	LassoWsfProfile *profile;
 	int rc;
+	gchar *service_type;
+
+	/* FIXME: another way to get the service type ? */
+	{
+		LassoSoapEnvelope *envelope;
+		LassoDstQuery *request;
+		xmlDoc *doc;
+		doc = xmlParseMemory(message, strlen(message));
+		xmlNode *xmlnode = xmlSecFindNode(xmlDocGetRootElement(doc), xmlSecNodeSignature,
+						  xmlSecDSigNs);
+		if (xmlnode) {
+			xmlUnlinkNode(xmlnode);
+			xmlFreeNode(xmlnode);
+		}
+		envelope = LASSO_SOAP_ENVELOPE(
+			lasso_node_new_from_xmlNode(xmlDocGetRootElement(doc)));
+		request = LASSO_DST_QUERY(envelope->Body->any->data);
+		service_type = g_strdup(request->hrefServiceType);
+		xmlFreeDoc(doc);
+	}
 
 	profile = LASSO_WSF_PROFILE(service);
-	rc = lasso_wsf_profile_process_soap_request_msg(profile, message, security_mech_id);
-	if (rc) {
+	rc = lasso_wsf_profile_process_soap_request_msg(profile, message, service_type,
+							security_mech_id);
+	if (rc)
 		return rc;
-	}
-
-	/* Verify needed credential */
-	if (lasso_security_mech_id_is_saml_authentication(security_mech_id) == TRUE) {
-		int res = lasso_wsf_profile_verify_saml_authentication(LASSO_WSF_PROFILE(service));
-		if (res < 0)
-			return res;
-	}
 
 	query = LASSO_DST_QUERY(profile->request);
 	if (query->ResourceID)
@@ -318,12 +397,19 @@ lasso_data_service_build_response_msg(LassoDataService *service)
 	profile = LASSO_WSF_PROFILE(service);
 	request = LASSO_DST_QUERY(profile->request);
 
+	envelope = profile->soap_envelope_response;
+
+	if (service->private_data->fault != NULL) {
+		envelope->Body->any = g_list_append(
+			envelope->Body->any, service->private_data->fault);
+		return lasso_wsf_profile_build_soap_response_msg(profile);
+	}
+
 	response = lasso_dst_query_response_new(
 		lasso_utility_status_new(LASSO_DST_STATUS_CODE_OK));
 	profile->response = LASSO_NODE(response);
 	response->prefixServiceType = g_strdup(request->prefixServiceType);
 	response->hrefServiceType = g_strdup(request->hrefServiceType);
-	envelope = profile->soap_envelope_response;
 	envelope->Body->any = g_list_append(envelope->Body->any, response);
 
 	doc = xmlNewDoc((xmlChar*)"1.0");
@@ -485,16 +571,44 @@ lasso_data_service_process_query_response_msg(LassoDataService *service,
 {
 	int rc;
 	LassoDstQueryResponse *response;
+	LassoSoapFault *fault = NULL;
+	LassoIsRedirectRequest *redirect_request = NULL;
+	GList *iter;
 
 	rc = lasso_wsf_profile_process_soap_response_msg(LASSO_WSF_PROFILE(service), message);
 	if (rc) return rc;
 
-	if (! LASSO_IS_DST_QUERY_RESPONSE(LASSO_WSF_PROFILE(service)->response))
+	/* Process Soap Faults response */
+	iter = LASSO_WSF_PROFILE(service)->soap_envelope_response->Body->any;
+	while (iter) {
+		if (LASSO_IS_SOAP_FAULT(iter->data) == TRUE) {
+			fault = LASSO_SOAP_FAULT(iter->data);
+			break;
+		}
+		iter = iter->next;
+	}
+	if (!fault)
+		return 0;
+
+	iter = fault->Detail->any;
+	while (iter) {
+		if (LASSO_IS_IS_REDIRECT_REQUEST(iter->data) == TRUE) {
+			redirect_request = LASSO_IS_REDIRECT_REQUEST(iter->data);
+			break;
+		}
+		iter = iter->next;
+	}
+	if (redirect_request)
+		return LASSO_SOAP_FAULT_REDIRECT_REQUEST;
+
+	return 0;
+
+	/*if (! LASSO_IS_DST_QUERY_RESPONSE(LASSO_WSF_PROFILE(service)->response))
 		return LASSO_ERROR_UNDEFINED;
 
 	response = LASSO_DST_QUERY_RESPONSE(LASSO_WSF_PROFILE(service)->response);
 	if (response->Status == NULL || strcmp(response->Status->code, "OK") != 0)
-		return LASSO_ERROR_UNDEFINED;
+	return LASSO_ERROR_UNDEFINED;*/
 
 	return 0;
 }
@@ -567,9 +681,11 @@ lasso_data_service_process_modify_msg(LassoDataService *service,
 	LassoDstModify *modify;
 	LassoWsfProfile *profile;
 	int rc;
+	gchar *service_type;
 
 	profile = LASSO_WSF_PROFILE(service);
-	rc = lasso_wsf_profile_process_soap_request_msg(profile, modify_soap_msg, security_mech_id);
+	rc = lasso_wsf_profile_process_soap_request_msg(profile, modify_soap_msg, service_type,
+							security_mech_id);
 	if (rc) {
 		return rc;
 	}
@@ -617,6 +733,7 @@ lasso_data_service_set_offering(LassoDataService *service,
 	service->private_data->offering = g_object_ref(offering);
 }
 
+
 /*****************************************************************************/
 /* overrided parent class methods */
 /*****************************************************************************/
@@ -656,6 +773,7 @@ instance_init(LassoDataService *service)
 {
 	service->resource_data = NULL;
 	service->private_data = g_new0(LassoDataServicePrivate, 1);
+	service->private_data->fault = NULL;
 }
 
 static void
