@@ -1,4 +1,4 @@
-/* $Id: lib_federation_termination_notification.h,v 1.13 2005/01/22 15:57:55 eraviart Exp $ 
+/* $Id: lib_federation_termination_notification.h,v 1.14 2005/11/20 15:38:19 fpeters Exp $ 
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
@@ -74,8 +74,8 @@ struct _LassoLibFederationTerminationNotificationClass {
 };
 
 LASSO_EXPORT GType lasso_lib_federation_termination_notification_get_type(void);
-LASSO_EXPORT LassoSamlpRequestAbstract* lasso_lib_federation_termination_notification_new(void);
-LASSO_EXPORT LassoSamlpRequestAbstract* lasso_lib_federation_termination_notification_new_full(
+LASSO_EXPORT LassoNode* lasso_lib_federation_termination_notification_new(void);
+LASSO_EXPORT LassoNode* lasso_lib_federation_termination_notification_new_full(
 		char *providerID, LassoSamlNameIdentifier *nameIdentifier,
 		LassoSignatureType sign_type, LassoSignatureMethod sign_method);
 
