@@ -1,4 +1,4 @@
-/* $Id: lib_logout_response.h,v 1.7 2005/01/22 15:57:55 eraviart Exp $ 
+/* $Id: lib_logout_response.h,v 1.8 2005/11/20 15:38:19 fpeters Exp $ 
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
@@ -58,9 +58,9 @@ struct _LassoLibLogoutResponseClass {
 };
 
 LASSO_EXPORT GType lasso_lib_logout_response_get_type(void);
-LASSO_EXPORT LassoSamlpResponseAbstract* lasso_lib_logout_response_new(void);
+LASSO_EXPORT LassoNode* lasso_lib_logout_response_new(void);
 
-LASSO_EXPORT LassoSamlpResponseAbstract* lasso_lib_logout_response_new_full(
+LASSO_EXPORT LassoNode* lasso_lib_logout_response_new_full(
 		char *providerID, const char *statusCodeValue,
 		LassoLibLogoutRequest *request,
 		LassoSignatureType sign_type, LassoSignatureMethod sign_method);
