@@ -1,4 +1,4 @@
-/* $Id: lib_name_identifier_mapping_response.c,v 1.19 2005/01/22 15:57:55 eraviart Exp $ 
+/* $Id: lib_name_identifier_mapping_response.c,v 1.20 2005/11/20 15:38:19 fpeters Exp $ 
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
@@ -115,7 +115,7 @@ lasso_lib_name_identifier_mapping_response_get_type()
  *
  * Return value: a newly created #LassoLibNameIdentifierMappingResponse object
  **/
-LassoSamlpResponseAbstract*
+LassoNode*
 lasso_lib_name_identifier_mapping_response_new()
 {
 	return g_object_new(LASSO_TYPE_LIB_NAME_IDENTIFIER_MAPPING_RESPONSE, NULL);
@@ -135,7 +135,7 @@ lasso_lib_name_identifier_mapping_response_new()
  *
  * Return value: a newly created #LassoLibNameIdentifierMappingResponse object
  **/
-LassoSamlpResponseAbstract*
+LassoNode*
 lasso_lib_name_identifier_mapping_response_new_full(char *providerID, const char *statusCodeValue,
 		LassoLibNameIdentifierMappingRequest *request,
 		LassoSignatureType sign_type, LassoSignatureMethod sign_method)
@@ -155,5 +155,5 @@ lasso_lib_name_identifier_mapping_response_new_full(char *providerID, const char
 	response->Status->StatusCode = lasso_samlp_status_code_new();
 	response->Status->StatusCode->Value = g_strdup(statusCodeValue);
 
-	return LASSO_SAMLP_RESPONSE_ABSTRACT(response);
+	return LASSO_NODE(response);
 }
